@@ -1,12 +1,12 @@
 #!/usr/bin/perl -w
 #############################################################################
-## Name:        demo.pl
+## Name:        demo/demo.pl
 ## Purpose:     wxPerl demo ( tries to be as cool as the wxPython one )
 ## Author:      Mattia Barbon
 ## Modified by:
-## Created:      1/ 5/2001
-## RCS-ID:      $Id: demo.pl,v 1.18 2003/08/05 17:23:47 mbarbon Exp $
-## Copyright:   (c) 2001-2003 Mattia Barbon
+## Created:     01/05/2001
+## RCS-ID:      $Id: demo.pl,v 1.23 2005/06/11 06:43:57 mbarbon Exp $
+## Copyright:   (c) 2001-2003, 2005 Mattia Barbon
 ## Licence:     This program is free software; you can redistribute it and/or
 ##              modify it under the same terms as Perl itself
 #############################################################################
@@ -207,7 +207,15 @@ my @demos =
   ( [ 'wxPerl demo', the_demo ],
     [ 'Non-managed windows',
       [
-       [ 'HtmlWindow', demo( 'wxHtmlWindow' ) ],
+       [ 'HtmlWindow',
+         [
+          [ 'Simple HtmlWindow', demo( 'wxHtmlWindow' ) ],
+          [ 'Dynamic HTML', demo( 'wxHtmlDynamic' ) ],
+          ( Wx::wxVERSION >= 2.005 ?
+            [ 'Custom Tags', demo( 'wxHtmlTag' ) ] :
+            () ),
+         ],
+       ],
        [ 'Grid',
          [
           [ 'Simple Grid', demo( 'wxGrid' ) ],
@@ -229,6 +237,9 @@ my @demos =
       [
        [ 'CalendarCtrl', demo( 'wxCalendarCtrl' ) ],
        [ 'CheckListBox', demo( 'wxCheckListBox' ) ],
+       ( Wx::wxVERSION >= 2.005 ?
+         [ 'DatePickerCtrl', demo( 'wxDatePickerCtrl' ) ] :
+         () ),
        [ 'ListCtrl', demo( 'wxListCtrl' ) ],
        [ 'ScrollBar', demo( 'wxScrollBar' ) ],
       ],
@@ -238,7 +249,7 @@ my @demos =
        [ 'BoxSizer', demo( 'wxBoxSizer' ) ],
        [ 'GridSizer', demo( 'wxGridSizer' ) ],
        [ 'FrexGridSizer', demo( 'wxFlexGridSizer' ) ],
-       [ 'NotebookSizer', demo( 'wxNotebookSizer' ) ],
+#       [ 'NotebookSizer', demo( 'wxNotebookSizer' ) ],
       ],
     ],
     [ 'Contrib',
@@ -251,11 +262,12 @@ my @demos =
     [ 'Miscellaneous',
       [
        [ 'FileSystem', demo( 'wxFileSystem' ) ],
-       [ 'Dynamic HTML', demo( 'wxHtmlDynamic' ) ],
        [ 'Locale', demo( 'wxLocale' ) ],
        [ 'MDI', demo( 'MDI', 'MDIDemo' ) ],
        [ 'Printing', demo( 'Printing' ) ],
-       [ 'Unicode', demo( 'Unicode', 'UnicodeDemo' ), 3.0 ],
+       ( Wx::wxUNICODE() ?
+         [ 'Unicode', demo( 'Unicode', 'UnicodeDemo' ) ] :
+         () ),
        [ 'Clipboard', demo( 'wxClipboard' ) ],
        [ 'Drag&Drop', demo( 'DragDrop', 'DNDDemo' ) ],
        [ 'Process', demo( 'wxProcess' ) ],
@@ -314,7 +326,8 @@ sub new {
                                 wxDefaultPosition, wxDefaultSize,
                                 wxTE_READONLY|wxTE_MULTILINE
                                |wxNO_FULL_REPAINT_ON_RESIZE );
-  $this->{OLDLOG} = Wx::Log::SetActiveTarget( Wx::LogTextCtrl->new( $text ) );
+  my $log = Wx::LogTextCtrl->new( $text );
+  $this->{OLDLOG} = Wx::Log::SetActiveTarget( $log );
 
   # create main notebook
   my $nb = Wx::Notebook->new( $split2, -1, wxDefaultPosition, wxDefaultSize,
